@@ -26,6 +26,8 @@ import (
 	"os"
 	"strings"
 	"testing"
+
+	"github.com/minio/minio-go/pkg/policy"
 )
 
 type customReader struct{}
@@ -76,22 +78,41 @@ func TestGetReaderSize(t *testing.T) {
 	}
 
 	// Create request channel.
-	reqCh := make(chan readRequest)
+	reqCh := make(chan getRequest, 1)
 	// Create response channel.
-	resCh := make(chan readResponse)
+	resCh := make(chan getResponse, 1)
 	// Create done channel.
 	doneCh := make(chan struct{})
-	// objectInfo.
-	objectInfo := ObjectInfo{Size: 10}
-	objectReader := newObject(reqCh, resCh, doneCh, objectInfo)
-	defer objectReader.Close()
 
-	size, err = getReaderSize(objectReader)
+	objectInfo := ObjectInfo{Size: 10}
+	// Create the first request.
+	firstReq := getRequest{
+		isReadOp:   false, // Perform only a HEAD object to get objectInfo.
+		isFirstReq: true,
+	}
+	// Create the expected response.
+	firstRes := getResponse{
+		objectInfo: objectInfo,
+	}
+	// Send the expected response.
+	resCh <- firstRes
+
+	// Test setting size on the first request.
+	objectReaderFirstReq := newObject(reqCh, resCh, doneCh)
+	defer objectReaderFirstReq.Close()
+	// Not checking the response here...just that the reader size is correct.
+	_, err = objectReaderFirstReq.doGetRequest(firstReq)
+	if err != nil {
+		t.Fatal("Error:", err)
+	}
+
+	// Validate that the reader size is the objectInfo size.
+	size, err = getReaderSize(objectReaderFirstReq)
 	if err != nil {
 		t.Fatal("Error:", err)
 	}
 	if size != int64(10) {
-		t.Fatalf("Reader length doesn't match got: %v, want: %v", size, 10)
+		t.Fatalf("Reader length doesn't match got: %d, wanted %d", size, objectInfo.Size)
 	}
 
 	fileReader, err := ioutil.TempFile(os.TempDir(), "prefix")
@@ -325,7 +346,7 @@ func TestBucketPolicyTypes(t *testing.T) {
 		"invalid":   false,
 	}
 	for bucketPolicy, ok := range want {
-		if BucketPolicy(bucketPolicy).isValidBucketPolicy() != ok {
+		if policy.BucketPolicy(bucketPolicy).IsValidBucketPolicy() != ok {
 			t.Fatal("Error")
 		}
 	}
@@ -333,24 +354,24 @@ func TestBucketPolicyTypes(t *testing.T) {
 
 // Tests optimal part size.
 func TestPartSize(t *testing.T) {
-	totalPartsCount, partSize, lastPartSize, err := optimalPartInfo(5000000000000000000)
+	_, _, _, err := optimalPartInfo(5000000000000000000)
 	if err == nil {
 		t.Fatal("Error: should fail")
 	}
-	totalPartsCount, partSize, lastPartSize, err = optimalPartInfo(5497558138880)
+	totalPartsCount, partSize, lastPartSize, err := optimalPartInfo(5497558138880)
 	if err != nil {
 		t.Fatal("Error: ", err)
 	}
-	if totalPartsCount != 9987 {
+	if totalPartsCount != 9103 {
 		t.Fatalf("Error: expecting total parts count of 9987: got %v instead", totalPartsCount)
 	}
-	if partSize != 550502400 {
+	if partSize != 603979776 {
 		t.Fatalf("Error: expecting part size of 550502400: got %v instead", partSize)
 	}
-	if lastPartSize != 241172480 {
+	if lastPartSize != 134217728 {
 		t.Fatalf("Error: expecting last part size of 241172480: got %v instead", lastPartSize)
 	}
-	totalPartsCount, partSize, lastPartSize, err = optimalPartInfo(5000000000)
+	_, partSize, _, err = optimalPartInfo(5000000000)
 	if err != nil {
 		t.Fatal("Error:", err)
 	}
@@ -361,13 +382,13 @@ func TestPartSize(t *testing.T) {
 	if err != nil {
 		t.Fatal("Error:", err)
 	}
-	if totalPartsCount != 9987 {
+	if totalPartsCount != 9103 {
 		t.Fatalf("Error: expecting total parts count of 9987: got %v instead", totalPartsCount)
 	}
-	if partSize != 550502400 {
+	if partSize != 603979776 {
 		t.Fatalf("Error: expecting part size of 550502400: got %v instead", partSize)
 	}
-	if lastPartSize != 241172480 {
+	if lastPartSize != 134217728 {
 		t.Fatalf("Error: expecting last part size of 241172480: got %v instead", lastPartSize)
 	}
 }
